<?php
/* $Id: chinese_traditional-big5.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/**
 * Last translation by: Siu Sun <siusun@best-view.net>
 * Follow by the original translation of Taiyen Hung x<yen789@pchome.com.tw>
 */

$charset = 'big5';
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$mysql_5_1_doc_lang = 'zh';

$day_of_week = array('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d, %Y, %I:%M %p';

$timespanfmt = '%s , %s p, %s  %s ';

$strAbortedClients = '';
$strAccessDenied = 'ڵs';
$strAccessDeniedCreateConfig = 'iAإ߳]w. AiQΦ %1$sw˵{%2$s إ߳]w.';
$strAccessDeniedExplanation = 'phpMyAdmin ճsu MySQL A, AڵFsu. z config.inc.php ˬdDW, nJW٤αKXνTOoǸƬOPtκ޲zHҴѪ MySQL AƬۦP';
$strAction = '';
$strAddAutoIncrement = "sW AUTO_INCREMENT ƭ";
$strAddConstraints = '[J';
$strAddDeleteColumn = 'sW/ ';
$strAddDeleteRow = 'sW/ zC';
$strAddFields = 'sW %s ';
$strAddHeaderComment = 'D[JӤH (\\n }s)';
$strAddIntoComments = '[JѤr';
$strAddNewField = 'W[s';
$strAddPrivilegesOnDb = 'HUƮw[Jv';
$strAddPrivilegesOnTbl = 'HUƪ[Jv';
$strAddSearchConditions = 'W[˯ ("where" lyD)';
$strAddToIndex = 'sW &nbsp;%s&nbsp; կ';
$strAddUser = 'sWϥΪ';
$strAddUserMessage = 'zwsWF@ӷsϥΪ.';
$strAdministration = 'tκ޲z';
$strAffectedRows = 'vTC: ';
$strAfter = 'b %s ';
$strAfterInsertBack = '^';
$strAfterInsertNewInsert = 'sW@O';
$strAfterInsertNext = 'ss@C';
$strAfterInsertSame = '^o';
$strAll = '';
$strAllTableSameWidth = 'HۦPeܩҦƪ?';
$strAlterOrderBy = 'ھ줺eƧǰO';
$strAnalyzeTable = 'Rƪ';
$strAnd = 'P';
$strAndThen = 'M';
$strAnIndex = 'ޤwgsW %s';
$strAny = '';
$strAnyHost = 'D';
$strAnyUser = 'ϥΪ';
$strApproximateCount = 'i౵. аѬ FAQ 3.11';
$strAPrimaryKey = 'DwgsW %s';
$strArabic = 'ԧBy';
$strArmenian = '^y';
$strAscending = 'W';
$strAtBeginningOfTable = 'ƪ}Y';
$strAtEndOfTable = 'ƪ';
$strAttr = 'ݩ';
$strAutodetect = '۰ʰ';
$strAutomaticLayout = '۰ʮ榡';

$strBack = '^W@';
$strBaltic = 'iùy';
$strBeginCut = '}l Ũ';
$strBeginRaw = '}l l';
$strBinary = 'GiX';
$strBinaryDoNotEdit = 'GiX - s';
$strBinaryLog = 'GiO';
$strBinLogEventType = 'ƥ覡';
$strBinLogInfo = '';
$strBinLogName = 'Oɮ׺';
$strBinLogOriginalPosition = '즳m';
$strBinLogPosition = 'm';
$strBinLogServerId = 'A ID';
$strBookmarkAllUsers = 'ҦΪ̥iŪ';
$strBookmarkCreated = ' %s wإ';
$strBookmarkDeleted = 'ҤwgR.';
$strBookmarkLabel = 'ҦW';
$strBookmarkQuery = 'SQL yk';
$strBookmarkReplace = 'NۦPW٤';
$strBookmarkThis = 'N SQL yk[J';
$strBookmarkView = 'd';
$strBrowse = 's';
$strBrowseDistinctValues = 'sPƭ';
$strBrowseForeignValues = 's~ӭ';
$strBufferPool = 'wİ';
$strBufferPoolActivity = 'wİϬʲv';
$strBufferPoolUsage = 'wİϨϥΪŶ';
$strBufferReadMisses = 'Ū|';
$strBufferReadMissesInPercent = 'Ū| %';
$strBufferWriteWaits = 'gJ';
$strBufferWriteWaitsInPercent = 'gJ %';
$strBulgarian = 'O[QȻy';
$strBusyPages = 'c';
$strBzError = 'phpMyAdmin LkY]o php  Bz2 Ҳտ~. jCnD phpMyAdmin ]wɳ]w <code>$cfg[\'BZipDump\']</code> <code>FALSE</code>. pGQϥ Bz2 Y\,Чs php ̷s. ԱаѬ php ~ %s .';
$strBzip = '"bzipped"';

$strCalendar = '';
$strCanNotLoadImportPlugins = 'LkŪJ~{, ˬdw˵{!';
$strCannotLogin = 'LknJ MySQL A';
$strCantLoad = 'LkŪ %s Ҳ,<br />ˬd PHP ]w';
$strCantLoadRecodeIconv = 'Ū iconv έssX{ӧ@rsXഫ, г]w php ӱҰʳoǼҲթΨ phpMyAdmin ϥΤrsXഫ\.';
$strCantRenameIdxToPrimary = 'LkNާW PRIMARY!';
$strCantUseRecodeIconv = 'sXҲŪ,ϥ iconv, libiconv  recode_string \. ˬdz php ]w.';
$strCardinality = 'էO';
$strCaseInsensitive = 'jpg۲';
$strCaseSensitive = 'jpg۲';
$strCentralEuropean = 'ڻy';
$strChange = 'ק';
$strChangeCopyMode = 'إ߷sϥΪ̤ΨϥάۦPv,  ...';
$strChangeCopyModeCopy = '... Od¨ϥΪ.';
$strChangeCopyModeDeleteAndReload = ' ... R¨ϥΪ̤έsŪvƪ.';
$strChangeCopyModeJustDelete = ' ... R¨ϥΪ.';
$strChangeCopyModeRevoke = ' ... oҦ¨ϥΪ̦ĤvçR.';
$strChangeCopyUser = 'nJT / ƻsϥΪ';
$strChangeDisplay = 'ܤ';
$strChangePassword = 'KX';
$strCharset = 'rsX (Charset)';
$strCharsetOfFile = 'rsXɮ:';
$strCharsets = 'rsX';
$strCharsetsAndCollations = 'rsXήչ';
$strCheckAll = '';
$strCheckOverhead = 'ˬdB~O (overhead)'; // nor sure yet.
$strCheckPrivs = 'dv';
$strCheckPrivsLong = 'd߸Ʈw &quot;%s&quot; v.';
$strCheckTable = 'ˬdƪ';
$strChoosePage = 'пܻݭns誺X';
$strColComFeat = '';
$strCollation = 'չ';
$strColumnNames = 'W';
$strColumnPrivileges = 'wv';
$strCommand = 'O';
$strComments = '';
$strCommentsForTable = 'COMMENTS FOR TABLE';  // keep in SQL statement
$strCompatibleHashing = 'MySQL&nbsp;4.0 ۮe';
$strCompleteInserts = 'ϥΧsWO';
$strCompression = 'Y';
$strCompressionWillBeDetected = 'JɮY|۰ˬd: %s';
$strConfigDefaultFileError = 'LkŪw]]w: "%1$s"';
$strConfigFileError = 'phpMyAdmin Ūz]w! oiO] php ykW~ php ɮצӦ.<br />йժUU誺s}Ҩìd php ~H. q`~Ӧ۬YB|F޸ΤO.<br />pGUsX{ťխ, YNSD.';
$strConfigureTableCoord = 'г]w %s ';
$strConnectionError = 'Lksu: ~]w.';
$strConnections = 'su';
$strConstraintsForDumped = 'ƥƪ';
$strConstraintsForTable = 'ƪ';
$strCookiesRequired = 'Cookies Ұʤ~nJ.';
$strCopy = 'ƻs';
$strCopyDatabaseOK = 'Ʈw %s wƻs %s';
$strCopyTable = 'ƻsƪG (榡 ƮwW<b>.</b>ƪW):';
$strCopyTableOK = 'wgNƪ %s ƻs %s.';
$strCopyTableSameNames = 'LkƻsۦPƪ!';
$strCouldNotKill = 'phpMyAdmin Lk_O %s. ioOwg.';
$strCreate = 'إ';
$strCreateDatabaseBeforeCopying = 'ƻseإ߸Ʈw (CREATE DATABASE)';
$strCreateIndex = 'sW &nbsp;%s&nbsp; կ';
$strCreateIndexTopic = 'sW@կ';
$strCreateNewDatabase = 'إ߷sƮw';
$strCreateNewTable = 'إ߷sƪƮw %s';
$strCreatePage = 'إ߷s@';
$strCreatePdfFeat = 'إ PDF';
$strCreationDates = 'إ/s/ˬd ';
$strCriteria = 'z';
$strCroatian = 'JùȻy';
$strCSV = 'CSV';  //USE ENG
$strCSVImportOptions = 'CSV ﶵ';
$strCSVOptions = 'CSV ﶵ';
$strCyrillic = '訽y';
$strCzech = 'Jy';
$strCzechSlovak = 'Jy';

$strDanish = 'y';
$strData = '';
$strDatabase = 'Ʈw';
$strDatabaseEmpty = 'ƮwW٨åJ!!';
$strDatabaseExportOptions = 'ƮwXﶵ';
$strDatabaseHasBeenDropped = 'Ʈw %s wQR';
$strDatabaseNoTable = 'oƮwSƪ!';
$strDatabases = 'Ʈw';
$strDatabasesDropped = '%s ӸƮww\R.';
$strDatabasesStats = 'Ʈwέp';
$strDatabasesStatsDisable = 'έpƾ';
$strDatabasesStatsEnable = 'Ұʲέpƾ';
$strDatabasesStatsHeavyTraffic = ': ҰʸƮwέpƾڥi|ͤjq Web A MySQL yq.';
$strDataDict = 'ƾڦr';
$strDataOnly = 'u';
$strDataPages = ']tƭ';
$strDBComment = 'ƮwѤr: ';
$strDBCopy = 'ƻsƮw';
$strDbPrivileges = 'wƮwv';
$strDBRename = 'ƮwW٨';
$strDbSpecific = 'wƮw';
$strDefault = 'w]';
$strDefaultEngine = 'o MySQL Aw]xsO %s ';
$strDefaultValueHelp = 'w]: ХuJӹw], Lݥ[Wϱ׽uΤ޸';
$strDefragment = 'zƪ';
$strDelayedInserts = 'ϥΩ𦡷sW';
$strDelete = 'R';
$strDeleteAndFlush = 'RϥΪ̤έsŪv.';
$strDeleteAndFlushDescr = 'oO@ӳ̲M䪺k,sŪvݤ@qɶ.';
$strDeleted = 'OwQR';
$strDeletedRows = 'wR:';
$strDeleteNoUsersSelected = 'åܻݭnRϥΪ!';
$strDeleting = 'R %s';
$strDelOld = 'ѦҨƪwsb. zƱRoǰѦҶ?';
$strDescending = '';
$strDescription = '';
$strDictionary = 'r';
$strDirtyPages = 'D';
$strDisabled = 'Ұ';
$strDisableForeignChecks = 'ȩw~ (Foreign Key) ˬd';
$strDisplayFeat = '\';
$strDisplayOrder = 'ܦ';
$strDisplayPDF = ' PDF n';
$strDoAQuery = 'HdҬd (UΦr : "%")';
$strDocu = '';
$strDoYouReally = 'zTwn ';
$strDrop = 'R';
$strDropDatabaseStrongWarning = 'zN|RӸƮw!';
$strDropUsersDb = 'RPϥΪ̬ۦPW٤Ʈw.';
$strDumpingData = 'CXHUƮwƾڡG';
$strDumpSaved = 'ƥwxɮ %s.';
$strDumpXRows = 'ƥ %s ,  %s }l.';
$strDynamic = 'ʺA';

$strEdit = 's';
$strEditPDFPages = 's PDF X';
$strEditPrivileges = 'sv';
$strEffective = '';
$strEmpty = 'M';
$strEmptyResultSet = 'MySQL Ǧ^dߵG (]iରGSŦX󪺰O)';
$strEnabled = 'Ұ';
$strEncloseInTransaction = 'ϥΨưȶ (Transaction) 覡';
$strEnd = '̫@';
$strEndCut = ' Ũ';
$strEndRaw = ' l';
$strEngineAvailable = '%s w䴩o MySQL A.';
$strEngineDisabled = '%s vo MySQL A.';
$strEngines = ''; 
$strEngineUnsupported = 'o MySQL ä %s xs.';
$strEnglish = '^y';
$strEnglishPrivileges = '`N: MySQL vWٷ|H^y';
$strError = '~';
$strErrorInZipFile = 'ZIP ɮ׿~:';
$strEscapeWildcards = 'UβŸ _  % Ta[J \ ';
$strEsperanto = '@ɻy';
$strEstonian = 'RFȻy';
$strExcelEdition = 'Excel ';
$strExcelOptions = 'Excel ﶵ';
$strExecuteBookmarked = 'Ҭd';
$strExplain = ' SQL';
$strExport = 'X';
$strExtendedInserts = 'sWҦ';
$strExtra = '[';

$strFailedAttempts = 'ե';
$strField = '';
$strFieldHasBeenDropped = 'ƪ %s wQR';
$strFields = '';
$strFieldsEmpty = ' `ƬOŪ! ';
$strFieldsEnclosedBy = 'uvϥΦrG';
$strFieldsEscapedBy = 'uESCAPEvϥΦrG';
$strFieldsTerminatedBy = 'ujvϥΦrG';
$strFileAlreadyExists = 'ɮ %s wsb,ЧɮצW٩οܡuмgvsbɮסvﶵ.';
$strFileCouldNotBeRead = 'Ū׵LkŪ';
$strFileNameTemplate = 'ɮצWټ˦';
$strFileNameTemplateDescriptionDatabase = 'ƮwW';
$strFileNameTemplateDescriptionServer = 'AW';
$strFileNameTemplateDescriptionTable = 'ƪW';
$strFileNameTemplateRemember = 'Od˦W';
$strFileToImport = 'Jɮ';
$strFixed = 'Tw';
$strFlushPrivilegesNote = ': phpMyAdmin  MySQL vƪoϥΪv. pGϥΪ̦ۦƪ, ƪeNiPڨϥΪ̱p. bopU, zb~e %ssJ%s vƪ.';
$strFlushQueryCache = 'jsyk֨';
$strFlushTable = 'jsƪ ("FLUSH")';
$strFlushTables = 'js () Ҧƪ';
$strFormat = '榡';
$strFormEmpty = '椺|@Ǹ!';
$strFreePages = 'm';
$strFullText = 'ܧr';
$strFunction = '';

$strGenBy = 'إ';
$strGeneralRelationFeat = '@p\';
$strGenerate = '';
$strGeneratePassword = 'ͱKX';
$strGenTime = 'إߤ';
$strGeorgian = '|NȻy';
$strGerman = 'wy';
$strGlobal = '';
$strGlobalPrivileges = 'v';
$strGlobalValue = '';
$strGo = '';
$strGrantOption = 'v';
$strGreek = 'þy';
$strGzip = '"gzipped"';

$strHandler = 'ާ@';
$strHasBeenAltered = 'wgק';
$strHasBeenCreated = 'wgإ';
$strHaveToShow = 'zݭn̤ܳܤ@';
$strHebrew = 'ƧBӻy';
$strHexForBinary = 'HQiƭܤGi';
$strHome = 'Dؿ';
$strHomepageOfficial = 'phpMyAdmin x';
$strHost = 'D';
$strHostEmpty = 'пJDW!';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 Xﶵ';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 Xﶵ';
$strHungarian = 'IQy';

$strIcelandic = 'Bqy'; 
$strId = 'ID'; // use eng
$strIdxFulltext = '˯';
$strIgnore = '';
$strIgnoreDuplicates = 'LЦC';
$strIgnoreInserts = 'ϥΩ[J (insert)'; 
$strImport = 'J';
$strImportFiles = 'Jɮ';
$strImportFormat = 'Jɮ׮榡';
$strImportSuccessfullyFinished = 'J\, @ %d yykw.';
$strIndex = ' INDEX';
$strIndexes = '';
$strIndexHasBeenDropped = ' %s wQR';
$strIndexName = 'ަW&nbsp;:';
$strIndexType = '&nbsp;:';
$strIndexWarningMultiple = 'hL@ %s wإߨ `%s` ';
$strIndexWarningPrimary = 'D PRIMARY   INDEX Pɶ]w `%s` ';
$strIndexWarningTable = 'ƪ `%s` ްD';
$strIndexWarningUnique = 'ߤ@ UNIQUE   INDEX Pɶ]w `%s` ';
$strInnoDBAutoextendIncrement = '۰ʦjp';
$strInnoDBAutoextendIncrementDesc = 'ƪeq񺡮, ۰ʼWjeqjp.';
$strInnoDBBufferPoolSize = 'wİϤjp';
$strInnoDBBufferPoolSizeDesc = 'InnoDB ƪΩ֨ƤίޮɨϥΪOwĤjp.';
$strInnoDBDataFilePath = 'ɮ';
$strInnoDBDataHomeDir = 'ƥDؿ';
$strInnoDBDataHomeDirDesc = 'Ҧ InnoDB ɮתDƥؿm.';
$strInnoDBPages = '';
$strInnodbStat = 'InnoDB A';
$strInsecureMySQL = ']wɤ]w (rootnJΨSKX) Pw] MySQL vfۦPC MySQL Abow]]wB檺ܷ|ܮeQJIAz靈]whw|}C';
$strInsert = 'sW';
$strInsertAsNewRow = 'xssO';
$strInsertedRowId = 'sWƦC id:';
$strInsertedRows = 'sWC:';
$strInternalNotNecessary = '* pb InnoDB wsbɬOLݭn.';
$strInternalRelations = 'p';
$strInUse = 'ϥΤ';
$strInvalidAuthMethod = ']w]w~{Ҥ覡:';
$strInvalidColumn = ' (%s) Ϥ~.!';
$strInvalidColumnCount = 'ƥػݭnjs.';
$strInvalidCSVFieldCount = 'CSV ɮײ %d 椤`ƿ~.';
$strInvalidCSVFormat = 'Invalid format of CSV ɮײ %d 椤榡~.';
$strInvalidCSVParameter = 'CSV JɰѼƿ~: %s';
$strInvalidFieldAddCount = 'A̤֭n[J@.';
$strInvalidFieldCount = 'ƪֻ̤ݭn@.';
$strInvalidLDIImport = 'o~{䴩YJ!';
$strInvalidRowNumber = '%d O@ӦĪCƼƥ.';
$strInvalidServerHostname = 'A %1$s DWٿ~, ½d]w.';
$strInvalidServerIndex = 'A޿~: "%s"';

$strJapanese = 'y';
$strJoins = 'X';
$strJumpToDB = 'Ʈw &quot;%s&quot;.';
$strJustDelete = 'uqvƮwRϥΪ.';
$strJustDeleteDescr = ' &quot;R&quot; ϥΪ̤MnJƮwܭsJƮw.';

$strKeepPass = 'ФnKX';
$strKeyCache = '֨';
$strKeyname = 'W';
$strKill = 'Kill'; //should expressed in English
$strKorean = 'y';

$strLandscape = 'V';
$strLanguageFileNotFound = '䤣yɮ "%1$s".';
$strLanguageUnknown = 'Wy: %1$s.';
$strLatchedPages = 'W';
$strLaTeX = 'LaTeX';  // use eng
$strLatexCaption = 'ƪD';
$strLatexContent = 'ƪ __TABLE__ e';
$strLatexContinued = '(s)';
$strLatexContinuedCaption = 'sƪD';
$strLatexIncludeCaption = ']AƪD';
$strLatexLabel = 'аOW';
$strLaTeXOptions = 'LaTeX ﶵ';
$strLatexStructure = 'ƪ __TABLE__ c';
$strLatvian = 'ԲȻy';
$strLDI = 'CSV ϥ LOAD DATA';
$strLDIImportOptions = 'CSV Jϥ LOAD DATA ﶵ';
$strLDILocal = 'ϥ LOCAL r';
$strLengthSet = '/X*';
$strLimitNumRows = 'O/C';
$strLinesTerminatedBy = 'uU@vϥΦrG';
$strLinkNotFound = '䤣s';
$strLinksTo = 's';
$strLithuanian = '߳{y';
$strLocalhost = 'a';
$strLocationTextfile = 'rɮתm';
$strLogin = 'nJ';
$strLoginInformation = 'nJT';
$strLogout = 'nXt';
$strLogPassword = 'KX:';
$strLogServer = 'A';
$strLogUsername = 'nJW:';
$strLongOperation = 'oӧ@~ҥήɶ|, ~?';

$strMaxConnects = '̤jsuƥ';
$strMaximalQueryLength = 'إߤd̤߳j';
$strMaximumSize = '̤jeq: %s%s'; 
$strMbExtensionMissing = '䤣 PHP  mbstring sXҲ, SoӼҲ, phpMyAdmin LkǽTarr, ӥiಣͰD.';
$strMbOverloadWarning = 'Ab PHP ]wҰʤF mbstring.func_overload ﶵ, oӿﶵȮɤݮe phpMyAdmin , Ai|l!';
$strMIME_available_mime = 'iϥ MIME ';
$strMIME_available_transform = 'iϥഫ覡';
$strMIME_description = '';
$strMIME_MIMEtype = 'MIME ';
$strMIME_nodescription = 'oഫ覡S.<br />ЦV@̬d %s Oƻγ~.';
$strMIME_transformation = 'sഫ覡';
$strMIME_transformation_note = 'iϥΤഫ覡ﶵ MINE ഫﶵ, Ьd %sഫ覡%s';
$strMIME_transformation_options = 'ഫ覡ﶵ';
$strMIME_transformation_options_note = 'ХΥHU榡Jഫﶵ: \'a\', 100, b,\'c\'...<br />pzݭnJϱ׽u ("\") γ޸ ("\'") ЦA[Wϱ׽u (Ҧp \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME HܬOSjഫ\';
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  // keep in SQL statement
$strModifications = 'קwxs';
$strModify = 'ק';
$strModifyIndexTopic = 'ק';
$strMoveTable = 'ʸƪG(榡 ƮwW<b>.</b>ƪW)';
$strMoveTableOK = 'ƪ %s wgʨ %s.';
$strMoveTableSameNames = 'LkʨۦPƪ!';
$strMultilingual = 'hy';
$strMyISAMDataPointerSize = 'ƫФjp';
$strMyISAMDataPointerSizeDesc = 'w]ƫФjpɷH CREATE TABLE إ MyISAM ƪ, ӨõL]w̤jC (MAX_ROWS) , N|H짹լ]wjp';
$strMyISAMMaxExtraSortFileSize = '{ɮ׫إ߯ޮɳ̤jeq';
$strMyISAMMaxExtraSortFileSizeDesc = 'p{ɮץΧ@ֳt MyISAM ޮɤjoӳ]weq, ĳϥW֨覡.';
$strMyISAMMaxSortFileSize = '{ɱƧɮ׳̤jeq';
$strMyISAMMaxSortFileSizeDesc = 'MySQL Ω󭫫 MyISAM  (REPAIR TABLE, ALTER TABLE,  LOAD DATA INFILE) ɪ{ɮפjp.';
$strMyISAMRecoverOptions = '۰ʭ״_Ҧ';
$strMyISAMRecoverOptionsDesc = 'oӼҦN|۰ʭ״_la MyISAM ƪ, pPAҰʳ]w[J --myisam-recover ﶵ.';
$strMyISAMRepairThreads = '״_u@';
$strMyISAMRepairThreadsDesc = 'pƭȤj 1 , MyISAM ƪ״_ɤޱN|HPBإ.';
$strMyISAMSortBufferSize = 'ƧǽwĤjp';
$strMyISAMSortBufferSizeDesc = 'oӽwĤjpOtb״_ƪO (REPAIR TABLE) B CREATE INDEX  ALTER TABLE O, ΩƧ MyISAM ޤ';
$strMySQLCharset = 'MySQL rsX';
$strMysqlClientVersion = 'MySQL Ȥݪ';
$strMySQLConnectionCollation = 'MySQL suչ';
$strMySQLSaid = 'MySQL Ǧ^G ';
$strMySQLShowProcess = 'ܵ{ (Process)';
$strMySQLShowStatus = ' MySQL 檬A';
$strMySQLShowVars = ' MySQL tܼ';

$strName = 'W';
$strNext = 'U@';
$strNo = ' _ ';
$strNoActivity = 'ѩwmFF %s , ЭsnJ';
$strNoDatabases = 'SƮw';
$strNoDatabasesSelected = 'SƮw.';
$strNoDescription = 'S';
$strNoDetailsForEngine = 'oxsõLԲӪA.';
$strNoDropDatabases = '"DROP DATABASE" Owg.';
$strNoExplain = 'L SQL';
$strNoFilesFoundInZip = ' ZIP ɮפ䤣ɮ!';
$strNoFrames = 'phpMyAdmin AXϥΦb䴩<b></b>s.';
$strNoIndex = 'Swwq!';
$strNoIndexPartsDefined = '޸٥wq!';
$strNoModification = 'Sܧ';
$strNone = 'A';
$strNoOptions = 'oخ榡õLﶵ';
$strNoPassword = 'αKX';
$strNoPermission = 'Web ASvxsɮ %s.';
$strNoPhp = ' PHP {X';
$strNoPrivileges = 'Sv';
$strNoRights = 'z{bSv!';
$strNoRowsSelected = 'õLƦCw';
$strNoSpace = 'Ŷxsɮ %s.';
$strNoTablesFound = 'ƮwSƪ';
$strNoThemeSupport = '䴩ڦ\, Ьdݳ]wפxsڦɮתƧ %s.';
$strNotNumber = 'oO@ӼƦr!';
$strNotOK = 'Tw';
$strNotSet = '<b>%s</b> ƪ䤣٥b %s ]w';
$strNoUsersFound = '䤣ϥΪ';
$strNoValidateSQL = 'Lˬd SQL';
$strNull = 'Null'; //should expressed in English
$strNumberOfFields = 'ƥ';
$strNumSearchResultsInTable = '%s ƲŦX - ƪ <i>%s</i>';
$strNumSearchResultsTotal = '<b>`p:</b> <i>%s</i> ƲŦX';
$strNumTables = 'Ӹƪ';

$strOK = 'Tw';
$strOpenNewWindow = '}ҷs phpMyAdmin ';
$strOperations = '޲z';
$strOperator = 'ާ@';
$strOptimizeTable = '̨ΤƸƪ';
$strOr = '';
$strOverhead = 'hl';
$strOverwriteExisting = 'мgwsbɮ';

$strPageNumber = 'X:';
$strPagesToBeFlushed = 'js';
$strPaperSize = 'ȱijp';
$strPartialImport = 'J';
$strPartialText = 'ܳr';
$strPassword = 'KX';
$strPasswordChanged = '%s KXw\.';
$strPasswordEmpty = 'пJKX!';
$strPasswordHashing = 'KX';
$strPasswordNotSame = 'ĤGJKXP!';
$strPDF = 'PDF';  // USE ENG
$strPdfDbSchema = '"%s" Ʈwn -  %s ';
$strPdfInvalidTblName = 'ƪ "%s" sb!';
$strPdfNoTables = 'Sƪ';
$strPDFOptions = 'PDF ﶵ';
$strPDFReportTitle = 'iD';
$strPerHour = 'Cp';
$strPerMinute = 'C';
$strPerSecond = 'C';
$strPersian = 'iy';
$strPhoneBook = 'qï';
$strPhp = 'إ PHP {X';
$strPHP40203 = 'zϥ PHP  4.2.3, o@r`rY~(mbstring). аѾ\ PHP γis 19404. phpMyAdmin äĳϥγoӪ PHP .';
$strPHPVersion = 'PHP ';
$strPmaDocumentation = 'phpMyAdmin ';
$strPmaUriError = ' b]wɤ]w <tt>$cfg[\'PmaAbsoluteUri\']</tt> !';
$strPolish = 'iy';
$strPortrait = 'V';
$strPos1 = 'Ĥ@';
$strPrevious = 'e@';
$strPrimary = 'D PRIMARY';
$strPrimaryKeyHasBeenDropped = 'DwQR';
$strPrimaryKeyName = 'D䪺W٥٬ PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b></b>OD䪺W٥HάO<b>ߤ@</b>@եD!)';
$strPrint = 'CL';
$strPrintView = 'CL˵';
$strPrintViewFull = 'CL˵ (ܧr)';
$strPrivDescAllPrivileges = ']AҦvFv (GRNANT).';
$strPrivDescAlter = 'e\ק{ƪc.';
$strPrivDescAlterRoutine = 'e\קΧRxs{.';
$strPrivDescCreateDb = 'e\إ߷sƮwθƪ.';
$strPrivDescCreateRoutine = 'e\إxs{';
$strPrivDescCreateTbl = 'e\إ߷sƪ.';
$strPrivDescCreateTmpTable = 'e\إ߼Ȯɩʸƪ.';
$strPrivDescCreateUser = 'e\إߡBRέsRWϥΪ̤f.';
$strPrivDescCreateView = 'e\إ߷s˵.';
$strPrivDescDelete = 'e\RO.';
$strPrivDescDropDb = 'e\RƮwθƪ.';
$strPrivDescDropTbl = 'e\Rƪ.';
$strPrivDescExecute = 'e\ wxs{.  MySQL L.';
$strPrivDescExecute5 = 'e\xs{.';
$strPrivDescFile = 'e\JοXƾڨɮ.';
$strPrivDescGrant = 'e\sWϥΪ̤vӵLݭsŪvƪ.';
$strPrivDescIndex = 'e\إߤΧR.';
$strPrivDescInsert = 'e\sWΨNƾ.';
$strPrivDescLockTables = 'e\W{ɳsuƪ.';
$strPrivDescMaxConnections = 'CpɨϥΪ̶}ҷssuƥ.';
$strPrivDescMaxQuestions = 'CpɨϥΪ̬dߪƥ.';
$strPrivDescMaxUpdates = 'CpɨϥΪ̧ƪμƾڪOƥ.';
$strPrivDescMaxUserConnections = 'CӨϥΪ̤PBsu.';
$strPrivDescProcess3 = 'e\LϥΪ̤{.';
$strPrivDescProcess4 = 'e\˵tΰM槹㤧d.';
$strPrivDescReferences = ' MySQL L.';
$strPrivDescReload = 'e\sŪA]wαjsA֨O.';
$strPrivDescReplClient = 'e\Τd slaves / masters bB.';
$strPrivDescReplSlave = 'ݭnƻs slaves.';
$strPrivDescSelect = 'e\Ūƾ.';
$strPrivDescShowDb = 'iŪӸƮwM.';
$strPrivDescShowView = 'e\ SHOW CREATE VIEW d.'; 
$strPrivDescShutdown = 'e\A.';
$strPrivDescSuper = 'e\su, NWLF̤jsu; Ω̰tκ޲zp]wvΤLϥΪ̫O.';
$strPrivDescUpdate = 'e\sƾ.';
$strPrivDescUsage = 'Sv.';
$strPrivileges = 'v';
$strPrivilegesReloaded = 'vw\sŪ.';
$strProcesses = 'Bz';
$strProcesslist = 'tΰM';
$strProtocolVersion = 'qTw';
$strPutColNames = 'NW٩b';

$strQBE = '̽dҬd (QBE)';
$strQBEDel = '';
$strQBEIns = 'sW';
$strQueryCache = 'dߧ֨';
$strQueryFrame = 'dߵ';
$strQueryOnDb = 'bƮw <b>%s</b>  SQL yk:';
$strQueryResultsOperations = 'dߵGާ@';
$strQuerySQLHistory = 'SQL {';
$strQueryStatistics = '<b>dڲέp</b>: έpҰʫ, @ %s Ӭd߶ǰe즹A.';
$strQueryTime = 'd߻ݮ %01.4f ';
$strQueryType = 'dߤ覡';
$strQueryWindowLock = 'nNoykл\쥻~SQLyk';

$strReadRequests = 'ŪnD';
$strReceived = '';
$strRecords = 'O';
$strReferentialIntegrity = 'ˬdܧ:';
$strRefresh = 's';
$strRelationalSchema = 'pn';
$strRelationNotWorking = 'pƪ[\ॼҰ, %sЫ%s dXD].';
$strRelations = 'p';
$strRelationsForTable = 'RELATIONS FOR TABLE';  // keep in SQL statement
$strRelationView = 'p˵';
$strReloadingThePrivileges = 'sŪv';
$strReloadPrivileges = 'sŪv';  //to translate
$strRemoveSelectedUsers = 'wܨϥΪ';
$strRenameDatabaseOK = 'Ʈw %s wW٬ %s';
$strRenameTable = 'NƪW';
$strRenameTableOK = 'wgNƪ %s W %s';
$strRepairTable = '״_ƪ';
$strReplaceNULLBy = 'N NULL N';
$strReplaceTable = 'HɮרNƪ';
$strReplication = 'ƻs';
$strReset = 'm';
$strResourceLimits = '귽';
$strReType = 'T{KX';
$strRevoke = '';
$strRevokeAndDelete = 'oϥΪ̩ҦĤvçR.';
$strRevokeAndDeleteDescr = 'ϥΪ̤M USAGE vvƪsŪ.';
$strRevokeMessage = 'zwoϥΪ̪v: %s';
$strRomanian = 'ùȻy';
$strRowLength = 'ƦC';
$strRows = 'ƦCC';
$strRowsFrom = 'OA}lC:';
$strRowSize = 'ƦCjp';
$strRowsModeFlippedHorizontal = ' (D)';
$strRowsModeHorizontal = '';
$strRowsModeOptions = 'ܬ %s 覡  Cj %s W';
$strRowsModeVertical = '';
$strRowsStatistic = 'ƦCέpƭ';
$strRunning = 'b %s ';
$strRunQuery = 'yk';
$strRunSQLQuery = 'bƮw %s HUO';
$strRunSQLQueryOnServer = 'A %s  SQL yk';
$strRussian = 'Xy';

$strSave = 'xs';
$strSaveOnServer = 'xsA %s ؿ';
$strScaleFactorSmall = 'ҭƤӲ, LkNϪb@';
$strSearch = 'j';
$strSearchFormTitle = 'jƮw';
$strSearchInTables = 'HUƪ:';
$strSearchNeedle = 'M䤧rμƭ (UΦr: "%"):';
$strSearchOption1 = '@դr';
$strSearchOption2 = 'Ҧr';
$strSearchOption3 = 'y';
$strSearchOption4 = 'HWhܪk (regular expression) j';
$strSearchResultsFor = 'j "<i>%s</i>" G %s:';
$strSearchType = 'M:';
$strSecretRequired = ']wɮײ{bݭnKX (passphrase) (blowfish_secret).';
$strSelectADb = 'пܸƮw';
$strSelectAll = '';
$strSelectBinaryLog = '˵GiO';
$strSelectFields = ' (ܤ֤@)';
$strSelectNumRows = 'dߤ';
$strSelectTables = 'ܸƪ';
$strSend = 'Uxs';
$strSent = 'eX';
$strServer = 'A';
$strServerChoice = 'ܦA';
$strServerNotResponding = 'AõL^';
$strServerStatus = 'BT';
$strServerStatusDelayedInserts = '𴡤J';
$strServerStatusUptime = 'o MySQL AwҰʤF %s. A %s Ұ.';
$strServerTabVariables = 'T';
$strServerTrafficNotes = '<b>Ayq</b>: oǪܤF MySQL A۱ҰʥHӪyqέpC';
$strServerVars = 'ATγ]w';
$strServerVersion = 'A';
$strSessionValue = '{Ǽƭ';
$strSetEnumVal = 'p榡O "enum"  "set", ШϥΥHU榡J: \'a\',\'b\',\'c\'...<br />pbƭȤWݭnJϱ׽u (\) γ޸ (\') , ЦA[Wϱ׽u (Ҧp \'\\\\xyz\' or \'a\\\'b\').';
$strShow = '';
$strShowAll = 'ܥ';
$strShowColor = 'C';
$strShowDatadictAs = 'ƾڦr榡';
$strShowFullQueries = 'ܧd';
$strShowGrid = 'ܮخ';
$strShowingBookmark = 'ܮ';
$strShowingRecords = 'ܰO';
$strShowOpenTables = 'ܶ}Ҹƪ';
$strShowPHPInfo = ' PHP T';
$strShowSlaveHosts = ' slave D';
$strShowSlaveStatus = ' slave A';
$strShowStatusReset = ']';
$strShowTableDimension = 'ܪjp';
$strShowTables = 'ܸƪ';
$strShowThisQuery = 's SQL yk ';
$strSimplifiedChinese = '²餤';
$strSingly = '(u|Ƨǲ{ɪO)';
$strSize = 'jp';
$strSkipQueries = '}lɲLh֦O (yk)';
$strSlovak = 'Jy';
$strSlovenian = '奧Ȼy';
$strSocketProblem = '( Ϊ̥ MySQL A socket åT]w)';
$strSort = 'Ƨ';
$strSortByKey = 'WƧ';
$strSorting = 'Ƨ';
$strSpaceUsage = 'wϥΪŶ';
$strSpanish = 'Zy';
$strSplitWordsWithSpace = 'CդrHŮ (" ") j.';
$strSQL = 'SQL'; // should express in english
$strSQLCompatibility = 'SQL ݮeҦ';
$strSQLExportType = 'X覡';
$strSQLImportOptions = 'SQL ﶵ';
$strSQLOptions = 'SQL ﶵ';
$strSQLParserBugMessage = 'oiOzF SQL R{@ǵ{~AвӤ߬dݱzykAˬd@U޸OTΨS|ALiX]iӦ۱zWɮ׮ɦb޸~aϥΤFGiXCziHզb MySQL ROCӻykCp MySQL AoX~HAoiUzhXDҦbCpzMѨMDAΦbR{X{~AbROCҦॿ`AбNӥyX{~ SQL ykXAñNHU"Ũ"@P:';
$strSQLParserUserError = 'iOz SQL ykX{~Ap MySQL AoX~HAoiUzhXDҦbC';
$strSQLQuery = 'SQL yk';
$strSQLResult = 'SQL dߵG';
$strSQPBugInvalidIdentifer = 'LĪѧOX (Invalid Identifer)';
$strSQPBugUnclosedQuote = '޸ (Unclosed quote)';
$strSQPBugUnknownPunctuation = 'IŸ (Unknown Punctuation String)';
$strStatCheckTime = '̫ˬd';
$strStatCreateTime = 'إ';
$strStatement = 'ԭz';
$strStatisticsOverrun = 'cA, p⾹i|X, O MySQL AѤέp~t.';
$strStatUpdateTime = '̫s';
$strStatus = 'A';
$strStorageEngine = 'xs';
$strStorageEngines = 'xs';
$strStrucCSV = 'CSV ';
$strStrucData = 'cP';
$strStrucExcelCSV = 'MS Excel  CSV 榡';
$strStrucNativeExcel = 'l MS Excel ';
$strStrucOnly = 'uc';
$strStructPropose = 'Rƪc';
$strStructure = 'c';
$strSubmit = 'eX';
$strSuccess = 'zSQLykwQ';
$strSum = '`p';
$strSwedish = 'y';
$strSwitchToDatabase = 'ಾƻsƮw';
$strSwitchToTable = 'wƻsƪ';

$strTable = 'ƪ';
$strTableAlreadyExists = 'ƪ %s wsb!';
$strTableComments = 'ƪѤr';
$strTableEmpty = 'пJƪW!';
$strTableHasBeenDropped = 'ƪ %s wQR';
$strTableHasBeenEmptied = 'ƪ %s wQM';
$strTableHasBeenFlushed = 'ƪ %s wQjs';
$strTableMaintenance = 'ƪ@';
$strTableOfContents = 'ؿ';
$strTableOptions = 'ƪﶵ';
$strTables = '%s ƪ';
$strTableStructure = 'ƪ榡G';
$strTakeIt = '';
$strTblPrivileges = 'wƪv';
$strTempData = 'Ȧs';
$strTextAreaLength = ' ѩ׭<br /> 줣s ';
$strThai = 'y';
$strTheme = 'ڦ';
$strThemeDefaultNotFound = '䤣w]GDD %s !';
$strThemeNoPreviewAvailable = 'õLw.';
$strThemeNotFound = '䤣GDD %s !';
$strThemeNoValidImgPath = '䤣GDD %s ]wϹ|!';
$strThemePathNotFound = '䤣GDD %s ]w|!';
$strThisHost = 'wD';
$strThreads = 'u{';
$strThreadSuccessfullyKilled = 'O %s w\.';
$strTime = 'ɶ';
$strToggleScratchboard = 'ഫK';
$strTotal = '`p';
$strTotalUC = '`@';
$strTraditionalChinese = 'c餤';
$strTraditionalSpanish = 'ǲΦZy';
$strTraffic = 'yq';
$strTransactionCoordinator = 'վ';
$strTransformation_application_octetstream__download = 'ܳsuӤUGi. Ĥ@ӿﶵOGiɮצW. ĤGӿﶵi]wiΪW٥Χ@ɮצW. pz]wFĤGӿﶵ, Ĥ@ӿﶵLݳ]w';
$strTransformation_application_octetstream__hex = 'HQi覡.';
$strTransformation_image_jpeg__inline = 'ܥiϹ; ﶵ; e,[H] (Oɭ즳)';
$strTransformation_image_jpeg__link = 'ܹϹsu (U).';
$strTransformation_image_png__inline = 'Ѭ image/jpeg: ';
$strTransformation_text_plain__external = 'u LINUX : ~{αNeHзǿJҦJ. X{зǿX. w]O, K HTML X. ѩOwz, zݭnۦs libraries/transformations/text_plain__external.inc.php Υ[JݭnϥΤu@. Ĥ@ӿﶵh֭ӵ{ݭnϥ, ĤGӿﶵo{Ѽ, ĤTӿﶵ, p]w 1 N|ϥ htmlspecialchars() ഫX (w]: 1). ĥ|ӿﶵ, p]w 1 N|[J NOWRAP 󤺮e椺, OXҦe|sƦ (w]: 1)';
$strTransformation_text_plain__formatted = 'Os쥻e榡. i Escaping Bz.';
$strTransformation_text_plain__imagelink = 'ܹϹγs, ƾڤeOɮצW; Ĥ@ӿﶵO}eq ( "http://domain.com/" ), ĤGӿﶵOeת,ĤTӿﶵOת.';
$strTransformation_text_plain__link = 'ܳs, ƾڤeOɮצW; Ĥ@ӿﶵO}eq ( "http://domain.com/" ), ĤGﶵOsD.';
$strTransformation_text_plain__sql = '榡Ƥr SQL dߤίSXyk.';
$strTransformation_text_plain__substr = 'uܳr. Ĥ@ӿﶵr}lXm (offset)  (w]: 0). ĤGӿﶵh֭ӦrX. dŬXlUҦr. ĤTӿﶵr^ܤr󵲧 (w]: ...) .';
$strTruncateQueries = 'Rwܬd';
$strTurkish = 'gըy';
$strType = 'A';

$strUkrainian = 'QJy';
$strUncheckAll = '';
$strUnicode = 'Τ@X (Unicode)';
$strUnique = 'ߤ@ UNIQUE';
$strUnknown = '';
$strUnselectAll = '';
$strUpdatePrivMessage = 'zwgsF %s v.';
$strUpdateProfileMessage = 'Ƥvgs.';
$strUpdateQuery = 'syk';
$strUpdComTab = 'аѬݻdߦps Column_comments ƪ';
$strUpgrade = 'zӧs %s %s Τ.';
$strUploadLimit = 'AդWjeqɮסAЬdݦ %s%s p󲤹L.';
$strUsage = 'ϥ';
$strUseBackquotes = 'bƪϥΤ޸';
$strUsedPhpExtensions = 'vϥ PHP XR';
$strUseHostTable = 'ϥΥDƪ';
$strUser = 'ϥΪ';
$strUserAlreadyExists = 'ϥΪ %s vsb!';
$strUserEmpty = 'пJϥΪ̦W!';
$strUserName = 'ϥΪ̦W';
$strUserNotFound = 'ܪϥΪ̦bvƪ䤣.';
$strUserOverview = 'ϥΪ̤@';
$strUsersDeleted = 'ܪϥΪ̤w\R.';
$strUsersHavingAccessToDb = 'iŪ &quot;%s&quot; ϥΪ';
$strUseTabKey = ' TAB U@Ӽƭ,  CTRL+V @HN';
$strUseTables = 'ϥθƪ';
$strUseTextField = 'rJ';
$strUseThisValue = 'ϥΦ';

$strValidateSQL = 'ˬd SQL';
$strValidatorError = 'SQL R{ҰʡAˬdO_wN %s%s  PHP ɮצwˡC';
$strValue = '';
$strVar = 'T';
$strVersionInformation = 'T';
$strView = '˵';
$strViewDump = '˵ƪƥn (dump schema)';
$strViewDumpDatabases = 'ܸƮwn (schema)';
$strViewDumpDB = '˵Ʈwƥn (dump schema)';
$strViewHasBeenDropped = '˵ %s vQR.';
$strViewMaxExactCount = 'oˬdwWL %s C, ԱаѬݦ%s%s.';

$strWebServerUploadDirectory = 'Web AWؿ';
$strWebServerUploadDirectoryError = ']wWؿ~Aϥ';
$strWelcome = 'wϥ %s';
$strWestEuropean = 'ڻy';
$strWildcard = 'UΦr';
$strWindowNotFound = 'ئaLks. iAwΧAsw]wҰʤFLks';
$strWithChecked = 'ܪƪG';
$strWriteRequests = 'gJnD';
$strWrongUser = '~ϥΪ̦W٩αKXAڵs';

$strXML = 'XML'; //USE ENG
	
$strYes = ' O ';

$strZeroRemovesTheLimit = ': ]woǿﶵ 0 (s) iѰ.';
$strZip = '"zipped"';


// To translate:
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate

$strAddClause = 'Add %s';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
$strXMLOptions = 'XML options';  //to translate
$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
$strCreateUserDatabase = 'Database for user';  //to translate
$strCreateUserDatabaseNone = 'None';  //to translate
$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
$strOpenDocumentText = 'Open Document Text';  //to translate
$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
$strInvalidTableName = 'Invalid table name';  //to translate
$strInvalidDatabase = 'Invalid database';  //to translate
$strServers = 'Servers';  //to translate
$strDelimiter = 'Delimiter';  //to translate
$strFunctions = 'Functions';  //to translate
$strProcedures = 'Procedures';  //to translate
$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
$strFontSize = 'Font size';  //to translate
$strLanguage = 'Language';  //to translate
$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strDocSQLOptions = 'DocSQL options';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
